See the documentation at `http://oct.readthedocs.org/en/latest/`_

.. _http://oct.readthedocs.org/en/latest/: http://oct.readthedocs.org/en/latest/

Github repository : `https://github.com/karec/oct`_

.. _https://github.com/karec/oct: https://github.com/karec/oct

Website: `http://www.oct-py.com/`_

.. _http://www.oct-py.com/: http://www.oct-py.com/
